#
# spec file for package hfst-ospell
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define _name hfst-ospell
%define libname libhfstospell11
Name:           hfst-ospell
Version:        0.5.4
Release:        1.1
Summary:        Spell checker library and tool based on HFST
License:        Apache-2.0
Group:          Productivity/Text/Spell
URL:            https://hfst.github.io/
Source0:        https://github.com/hfst/%{name}/releases/download/v%{version}/%{_name}-%{version}.tar.gz
Source99:       baselibs.conf
BuildRequires:  gcc-c++
BuildRequires:  libtool
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(icu-i18n)
BuildRequires:  pkgconfig(libarchive)

%description
Minimal HFST optimized lookup format based spell checker library and
a demonstrational implementation of command line based spell checker.

%package -n %{libname}
Summary:        HFST spell checker runtime libraries
Group:          System/Libraries
Provides:       libhfstospell = %{version}-%{release}
Obsoletes:      libhfstospell < %{version}-%{release}

%description -n %{libname}
HFST spell checker Runtime libraries for hfst-ospell

%package -n hfst-ospell-devel
Summary:        HFST spell checker development files
Group:          Development/Libraries/C and C++
Requires:       hfst-ospell = %{version}-%{release}

%description -n hfst-ospell-devel
Development headers and libraries for hfst-ospell

%prep
%autosetup -p1 -n %{_name}-%{version}

%build
# disable libxml++ as upstream requires version 2.6
# disable tinyxml2 as upstream requires version < 3.0
export CXXFLAGS="%{optflags} -DU_USING_ICU_NAMESPACE=1"
NO_CONFIGURE=1 ./autogen.sh
%configure \
    --disable-static \
    --disable-silent-rules \
    --without-libxmlpp \
    --without-tinyxml2
make %{?_smp_mflags}

%install
%make_install
find %{buildroot} -type f -name "*.la" -delete -print

%check
make %{?_smp_mflags} check

%post -n %{libname} -p /sbin/ldconfig
%postun -n %{libname} -p /sbin/ldconfig

%files
%doc AUTHORS NEWS
%{_bindir}/*
%{_mandir}/man1/*

%files -n %{libname}
%license COPYING
%{_libdir}/*.so.*

%files -n hfst-ospell-devel
%{_includedir}/*
%{_libdir}/pkgconfig/*
%{_libdir}/*.so

%changelog
* Fri May 10 2024 Timo Jyrinki <tjyrinki@suse.com>
- Update to 0.5.4, notable changes:
  * Fix minor memory leak
  * Try first-lower varianta instead of first-upper and all-lower
  * Re-set limits every step
  * Caching improvements
  * Fix build issues
- Drop gcc build patches, included upstream.
  * - gcc10-Fix-a-typo-in-wide-string-conversion-function-49.patch
  * - gcc13-fix.patch
* Thu Feb 22 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Use %%autosetup macro. Allows to eliminate the usage of deprecated
  %%patchN
* Thu Mar  9 2023 Martin Liška <mliska@suse.cz>
- Add upstream patch gcc13-fix.patch in order to support GCC 13.
* Fri Mar 27 2020 Martin Liška <mliska@suse.cz>
- Fix boo#1158318 by
  gcc10-Fix-a-typo-in-wide-string-conversion-function-49.patch.
* Thu Jan 16 2020 Tomáš Chvátal <tchvatal@suse.com>
- Update to 0.5.1 bsc#1164440:
  * change correction finding order (fixes issue #28)
  * require C++1y (C++14)
  * observe ICU namespacing (fixes issue #42)
* Fri Apr 20 2018 tchvatal@suse.com
- Add hack for icu 61 and newer -DU_USING_ICU_NAMESPACE=1
  * This needs to be removed when properly fixed upstream
* Fri Apr 20 2018 tchvatal@suse.com
- Version update to 0.5.0:
  * rename hfst_ol namespace to hfst_ospell to avoid conflicts
  * improve distinguishing between lemmas and tags in analysis
  * fix issue #37
  * avoid shadowing multicharacter ascii-beginning symbols
  * use minimal XML parsing to get locale, title, and description for Voikko and other frontends
* Thu Jan 18 2018 dimstar@opensuse.org
- Add baselibs.conf: build libhfstospell10-32bit, which is required
  by libvoikko1-32bit.
* Tue Apr 25 2017 tchvatal@suse.com
- Initial commit, required by libvoikko
